# NR metadata classes

Generated metadata classes. The metadata schema for these classes is at [github oarepo-model-builder-nr](https://github.com/Narodni-repozitar/oarepo-model-builder-nr/tree/main/oarepo_model_builder_nr/models) module.
